@@ -2,7 +2,7 @@ var node_itk = require('node-itk');
 
 var image = new node_itk.NodeImage('rgb',2);
 
-image.Read('rgb',2, 'Desert.jpg');
+image.Read('rgb',2, './Data/Desert.jpg');
 var rgb = image.GetRGBPixel(200,100)
 rgb = new node_itk.NodeRGB(255,0,0);
 
